Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1461)

Unified Diff: chrome/browser/renderer_host/render_widget_host_unittest.cc

Issue 113443: ChromeCanvas->gfx::Canvas (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_widget_host_unittest.cc
===================================================================
--- chrome/browser/renderer_host/render_widget_host_unittest.cc (revision 16147)
+++ chrome/browser/renderer_host/render_widget_host_unittest.cc (working copy)
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "app/gfx/chrome_canvas.h"
+#include "app/gfx/canvas.h"
#include "base/basictypes.h"
#include "base/keyboard_codes.h"
#include "base/scoped_ptr.h"
@@ -253,7 +253,7 @@
host_->set_view(view.get());
// Create a checkerboard background to test with.
- ChromeCanvas canvas(4, 4, true);
+ gfx::Canvas canvas(4, 4, true);
canvas.FillRectInt(SK_ColorBLACK, 0, 0, 2, 2);
canvas.FillRectInt(SK_ColorWHITE, 2, 0, 2, 2);
canvas.FillRectInt(SK_ColorWHITE, 0, 2, 2, 2);
@@ -288,7 +288,7 @@
#endif
#else
// TODO(port): Mac does not have ChromeCanvas. Maybe we can just change this
// test to use SkCanvas directly?
#endif
« no previous file with comments | « chrome/browser/printing/printed_document.cc ('k') | chrome/browser/renderer_host/render_widget_host_view_win.cc » ('j') | no next file with comments »
@@ -288,7 +288,7 @@
#endif
#else
- // TODO(port): Mac does not have ChromeCanvas. Maybe we can just change this
+ // TODO(port): Mac does not have gfx::Canvas. Maybe we can just change this
// test to use SkCanvas directly?
#endif

Powered by Google App Engine
This is Rietveld 408576698